data

package module
v0.0.0-...-d8b93a5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 6, 2026 License: MIT Imports: 4 Imported by: 1

Documentation

Index

Constants

const AggregatePayload_TypeID = 0xede74a3100507560

AggregatePayload_TypeID is the unique identifier for the type AggregatePayload.

const AggregateRow_TypeID = 0xf21b4c84e9812514

AggregateRow_TypeID is the unique identifier for the type AggregateRow.

const EgressPayload_TypeID = 0xe4febe4db3bcc071

EgressPayload_TypeID is the unique identifier for the type EgressPayload.

const EgressRow_TypeID = 0xecc4439552a3f2ea

EgressRow_TypeID is the unique identifier for the type EgressRow.

const Group_TypeID = 0xb562673936ae6f03

Group_TypeID is the unique identifier for the type Group.

const IngressPayload_TypeID = 0xb130c9ae0259d8b2

IngressPayload_TypeID is the unique identifier for the type IngressPayload.

const IngressRow_TypeID = 0xa16c37a3a0a3a200

IngressRow_TypeID is the unique identifier for the type IngressRow.

Variables

This section is empty.

Functions

func RegisterSchema

func RegisterSchema(reg *schemas.Registry)

Types

type AggregatePayload

type AggregatePayload capnp.Struct

func NewAggregatePayload

func NewAggregatePayload(s *capnp.Segment) (AggregatePayload, error)

func NewRootAggregatePayload

func NewRootAggregatePayload(s *capnp.Segment) (AggregatePayload, error)

func ReadRootAggregatePayload

func ReadRootAggregatePayload(msg *capnp.Message) (AggregatePayload, error)

func (AggregatePayload) AAvg

func (s AggregatePayload) AAvg() float64

func (AggregatePayload) ACount

func (s AggregatePayload) ACount() int64

func (AggregatePayload) ASum

func (s AggregatePayload) ASum() int64

func (AggregatePayload) BAvg

func (s AggregatePayload) BAvg() float64

func (AggregatePayload) CFirst

func (s AggregatePayload) CFirst() (string, error)

func (AggregatePayload) CFirstBytes

func (s AggregatePayload) CFirstBytes() ([]byte, error)

func (AggregatePayload) CLast

func (s AggregatePayload) CLast() (string, error)

func (AggregatePayload) CLastBytes

func (s AggregatePayload) CLastBytes() ([]byte, error)

func (AggregatePayload) DecodeFromPtr

func (AggregatePayload) DecodeFromPtr(p capnp.Ptr) AggregatePayload

func (AggregatePayload) EncodeAsPtr

func (s AggregatePayload) EncodeAsPtr(seg *capnp.Segment) capnp.Ptr

func (AggregatePayload) HasCFirst

func (s AggregatePayload) HasCFirst() bool

func (AggregatePayload) HasCLast

func (s AggregatePayload) HasCLast() bool

func (AggregatePayload) HasT2First

func (s AggregatePayload) HasT2First() bool

func (AggregatePayload) HasT2Last

func (s AggregatePayload) HasT2Last() bool

func (AggregatePayload) IsValid

func (s AggregatePayload) IsValid() bool

func (AggregatePayload) Message

func (s AggregatePayload) Message() *capnp.Message

func (AggregatePayload) OneCount

func (s AggregatePayload) OneCount() int64

func (AggregatePayload) OneSum

func (s AggregatePayload) OneSum() int64

func (AggregatePayload) RowidFirst

func (s AggregatePayload) RowidFirst() int64

func (AggregatePayload) RowidLast

func (s AggregatePayload) RowidLast() int64

func (AggregatePayload) Segment

func (s AggregatePayload) Segment() *capnp.Segment

func (AggregatePayload) SetAAvg

func (s AggregatePayload) SetAAvg(v float64)

func (AggregatePayload) SetACount

func (s AggregatePayload) SetACount(v int64)

func (AggregatePayload) SetASum

func (s AggregatePayload) SetASum(v int64)

func (AggregatePayload) SetBAvg

func (s AggregatePayload) SetBAvg(v float64)

func (AggregatePayload) SetCFirst

func (s AggregatePayload) SetCFirst(v string) error

func (AggregatePayload) SetCLast

func (s AggregatePayload) SetCLast(v string) error

func (AggregatePayload) SetOneCount

func (s AggregatePayload) SetOneCount(v int64)

func (AggregatePayload) SetOneSum

func (s AggregatePayload) SetOneSum(v int64)

func (AggregatePayload) SetRowidFirst

func (s AggregatePayload) SetRowidFirst(v int64)

func (AggregatePayload) SetRowidLast

func (s AggregatePayload) SetRowidLast(v int64)

func (AggregatePayload) SetT2First

func (s AggregatePayload) SetT2First(v string) error

func (AggregatePayload) SetT2Last

func (s AggregatePayload) SetT2Last(v string) error

func (AggregatePayload) String

func (s AggregatePayload) String() string

func (AggregatePayload) T2First

func (s AggregatePayload) T2First() (string, error)

func (AggregatePayload) T2FirstBytes

func (s AggregatePayload) T2FirstBytes() ([]byte, error)

func (AggregatePayload) T2Last

func (s AggregatePayload) T2Last() (string, error)

func (AggregatePayload) T2LastBytes

func (s AggregatePayload) T2LastBytes() ([]byte, error)

func (AggregatePayload) ToPtr

func (s AggregatePayload) ToPtr() capnp.Ptr

type AggregatePayload_Future

type AggregatePayload_Future struct{ *capnp.Future }

AggregatePayload_Future is a wrapper for a AggregatePayload promised by a client call.

func (AggregatePayload_Future) Struct

type AggregatePayload_List

type AggregatePayload_List = capnp.StructList[AggregatePayload]

AggregatePayload_List is a list of AggregatePayload.

func NewAggregatePayload_List

func NewAggregatePayload_List(s *capnp.Segment, sz int32) (AggregatePayload_List, error)

NewAggregatePayload creates a new list of AggregatePayload.

type AggregateRow

type AggregateRow capnp.Struct

func NewAggregateRow

func NewAggregateRow(s *capnp.Segment) (AggregateRow, error)

func NewRootAggregateRow

func NewRootAggregateRow(s *capnp.Segment) (AggregateRow, error)

func ReadRootAggregateRow

func ReadRootAggregateRow(msg *capnp.Message) (AggregateRow, error)

func (AggregateRow) DecodeFromPtr

func (AggregateRow) DecodeFromPtr(p capnp.Ptr) AggregateRow

func (AggregateRow) EncodeAsPtr

func (s AggregateRow) EncodeAsPtr(seg *capnp.Segment) capnp.Ptr

func (AggregateRow) Group

func (s AggregateRow) Group() (Group, error)

func (AggregateRow) HasGroup

func (s AggregateRow) HasGroup() bool

func (AggregateRow) HasPayload

func (s AggregateRow) HasPayload() bool

func (AggregateRow) IsValid

func (s AggregateRow) IsValid() bool

func (AggregateRow) Message

func (s AggregateRow) Message() *capnp.Message

func (AggregateRow) NewGroup

func (s AggregateRow) NewGroup() (Group, error)

NewGroup sets the group field to a newly allocated Group struct, preferring placement in s's segment.

func (AggregateRow) NewPayload

func (s AggregateRow) NewPayload() (AggregatePayload, error)

NewPayload sets the payload field to a newly allocated AggregatePayload struct, preferring placement in s's segment.

func (AggregateRow) Payload

func (s AggregateRow) Payload() (AggregatePayload, error)

func (AggregateRow) Segment

func (s AggregateRow) Segment() *capnp.Segment

func (AggregateRow) SetGroup

func (s AggregateRow) SetGroup(v Group) error

func (AggregateRow) SetPayload

func (s AggregateRow) SetPayload(v AggregatePayload) error

func (AggregateRow) String

func (s AggregateRow) String() string

func (AggregateRow) ToPtr

func (s AggregateRow) ToPtr() capnp.Ptr

type AggregateRow_Future

type AggregateRow_Future struct{ *capnp.Future }

AggregateRow_Future is a wrapper for a AggregateRow promised by a client call.

func (AggregateRow_Future) Group

func (AggregateRow_Future) Payload

func (AggregateRow_Future) Struct

func (f AggregateRow_Future) Struct() (AggregateRow, error)

type AggregateRow_List

type AggregateRow_List = capnp.StructList[AggregateRow]

AggregateRow_List is a list of AggregateRow.

func NewAggregateRow_List

func NewAggregateRow_List(s *capnp.Segment, sz int32) (AggregateRow_List, error)

NewAggregateRow creates a new list of AggregateRow.

type EgressPayload

type EgressPayload capnp.Struct

func NewEgressPayload

func NewEgressPayload(s *capnp.Segment) (EgressPayload, error)

func NewRootEgressPayload

func NewRootEgressPayload(s *capnp.Segment) (EgressPayload, error)

func ReadRootEgressPayload

func ReadRootEgressPayload(msg *capnp.Message) (EgressPayload, error)

func (EgressPayload) AAvg

func (s EgressPayload) AAvg() float64

func (EgressPayload) ACount

func (s EgressPayload) ACount() int64

func (EgressPayload) ASum

func (s EgressPayload) ASum() int64

func (EgressPayload) BAvg

func (s EgressPayload) BAvg() float64

func (EgressPayload) CFirst

func (s EgressPayload) CFirst() (string, error)

func (EgressPayload) CFirstBytes

func (s EgressPayload) CFirstBytes() ([]byte, error)

func (EgressPayload) CLast

func (s EgressPayload) CLast() (string, error)

func (EgressPayload) CLastBytes

func (s EgressPayload) CLastBytes() ([]byte, error)

func (EgressPayload) DecodeFromPtr

func (EgressPayload) DecodeFromPtr(p capnp.Ptr) EgressPayload

func (EgressPayload) EncodeAsPtr

func (s EgressPayload) EncodeAsPtr(seg *capnp.Segment) capnp.Ptr

func (EgressPayload) HasCFirst

func (s EgressPayload) HasCFirst() bool

func (EgressPayload) HasCLast

func (s EgressPayload) HasCLast() bool

func (EgressPayload) HasT2First

func (s EgressPayload) HasT2First() bool

func (EgressPayload) HasT2Last

func (s EgressPayload) HasT2Last() bool

func (EgressPayload) IsValid

func (s EgressPayload) IsValid() bool

func (EgressPayload) Message

func (s EgressPayload) Message() *capnp.Message

func (EgressPayload) OneCount

func (s EgressPayload) OneCount() int64

func (EgressPayload) OneSum

func (s EgressPayload) OneSum() int64

func (EgressPayload) RowidFirst

func (s EgressPayload) RowidFirst() int64

func (EgressPayload) RowidLast

func (s EgressPayload) RowidLast() int64

func (EgressPayload) Segment

func (s EgressPayload) Segment() *capnp.Segment

func (EgressPayload) SetAAvg

func (s EgressPayload) SetAAvg(v float64)

func (EgressPayload) SetACount

func (s EgressPayload) SetACount(v int64)

func (EgressPayload) SetASum

func (s EgressPayload) SetASum(v int64)

func (EgressPayload) SetBAvg

func (s EgressPayload) SetBAvg(v float64)

func (EgressPayload) SetCFirst

func (s EgressPayload) SetCFirst(v string) error

func (EgressPayload) SetCLast

func (s EgressPayload) SetCLast(v string) error

func (EgressPayload) SetOneCount

func (s EgressPayload) SetOneCount(v int64)

func (EgressPayload) SetOneSum

func (s EgressPayload) SetOneSum(v int64)

func (EgressPayload) SetRowidFirst

func (s EgressPayload) SetRowidFirst(v int64)

func (EgressPayload) SetRowidLast

func (s EgressPayload) SetRowidLast(v int64)

func (EgressPayload) SetT2First

func (s EgressPayload) SetT2First(v string) error

func (EgressPayload) SetT2Last

func (s EgressPayload) SetT2Last(v string) error

func (EgressPayload) String

func (s EgressPayload) String() string

func (EgressPayload) T2First

func (s EgressPayload) T2First() (string, error)

func (EgressPayload) T2FirstBytes

func (s EgressPayload) T2FirstBytes() ([]byte, error)

func (EgressPayload) T2Last

func (s EgressPayload) T2Last() (string, error)

func (EgressPayload) T2LastBytes

func (s EgressPayload) T2LastBytes() ([]byte, error)

func (EgressPayload) ToPtr

func (s EgressPayload) ToPtr() capnp.Ptr

type EgressPayload_Future

type EgressPayload_Future struct{ *capnp.Future }

EgressPayload_Future is a wrapper for a EgressPayload promised by a client call.

func (EgressPayload_Future) Struct

type EgressPayload_List

type EgressPayload_List = capnp.StructList[EgressPayload]

EgressPayload_List is a list of EgressPayload.

func NewEgressPayload_List

func NewEgressPayload_List(s *capnp.Segment, sz int32) (EgressPayload_List, error)

NewEgressPayload creates a new list of EgressPayload.

type EgressRow

type EgressRow capnp.Struct

func NewEgressRow

func NewEgressRow(s *capnp.Segment) (EgressRow, error)

func NewRootEgressRow

func NewRootEgressRow(s *capnp.Segment) (EgressRow, error)

func ReadRootEgressRow

func ReadRootEgressRow(msg *capnp.Message) (EgressRow, error)

func (EgressRow) DecodeFromPtr

func (EgressRow) DecodeFromPtr(p capnp.Ptr) EgressRow

func (EgressRow) EncodeAsPtr

func (s EgressRow) EncodeAsPtr(seg *capnp.Segment) capnp.Ptr

func (EgressRow) Group

func (s EgressRow) Group() (Group, error)

func (EgressRow) HasGroup

func (s EgressRow) HasGroup() bool

func (EgressRow) HasPayload

func (s EgressRow) HasPayload() bool

func (EgressRow) IsValid

func (s EgressRow) IsValid() bool

func (EgressRow) Message

func (s EgressRow) Message() *capnp.Message

func (EgressRow) NewGroup

func (s EgressRow) NewGroup() (Group, error)

NewGroup sets the group field to a newly allocated Group struct, preferring placement in s's segment.

func (EgressRow) NewPayload

func (s EgressRow) NewPayload() (EgressPayload, error)

NewPayload sets the payload field to a newly allocated EgressPayload struct, preferring placement in s's segment.

func (EgressRow) Payload

func (s EgressRow) Payload() (EgressPayload, error)

func (EgressRow) Segment

func (s EgressRow) Segment() *capnp.Segment

func (EgressRow) SetGroup

func (s EgressRow) SetGroup(v Group) error

func (EgressRow) SetPayload

func (s EgressRow) SetPayload(v EgressPayload) error

func (EgressRow) String

func (s EgressRow) String() string

func (EgressRow) ToPtr

func (s EgressRow) ToPtr() capnp.Ptr

type EgressRow_Future

type EgressRow_Future struct{ *capnp.Future }

EgressRow_Future is a wrapper for a EgressRow promised by a client call.

func (EgressRow_Future) Group

func (p EgressRow_Future) Group() Group_Future

func (EgressRow_Future) Payload

func (EgressRow_Future) Struct

func (f EgressRow_Future) Struct() (EgressRow, error)

type EgressRow_List

type EgressRow_List = capnp.StructList[EgressRow]

EgressRow_List is a list of EgressRow.

func NewEgressRow_List

func NewEgressRow_List(s *capnp.Segment, sz int32) (EgressRow_List, error)

NewEgressRow creates a new list of EgressRow.

type Group

type Group capnp.Struct

func NewGroup

func NewGroup(s *capnp.Segment) (Group, error)

func NewRootGroup

func NewRootGroup(s *capnp.Segment) (Group, error)

func ReadRootGroup

func ReadRootGroup(msg *capnp.Message) (Group, error)

func (Group) DecodeFromPtr

func (Group) DecodeFromPtr(p capnp.Ptr) Group

func (Group) EncodeAsPtr

func (s Group) EncodeAsPtr(seg *capnp.Segment) capnp.Ptr

func (Group) G1

func (s Group) G1() int64

func (Group) G2

func (s Group) G2() (string, error)

func (Group) G2Bytes

func (s Group) G2Bytes() ([]byte, error)

func (Group) HasG2

func (s Group) HasG2() bool

func (Group) IsValid

func (s Group) IsValid() bool

func (Group) Message

func (s Group) Message() *capnp.Message

func (Group) Segment

func (s Group) Segment() *capnp.Segment

func (Group) SetG1

func (s Group) SetG1(v int64)

func (Group) SetG2

func (s Group) SetG2(v string) error

func (Group) String

func (s Group) String() string

func (Group) ToPtr

func (s Group) ToPtr() capnp.Ptr

type Group_Future

type Group_Future struct{ *capnp.Future }

Group_Future is a wrapper for a Group promised by a client call.

func (Group_Future) Struct

func (f Group_Future) Struct() (Group, error)

type Group_List

type Group_List = capnp.StructList[Group]

Group_List is a list of Group.

func NewGroup_List

func NewGroup_List(s *capnp.Segment, sz int32) (Group_List, error)

NewGroup creates a new list of Group.

type IngressPayload

type IngressPayload capnp.Struct

func NewIngressPayload

func NewIngressPayload(s *capnp.Segment) (IngressPayload, error)

func NewRootIngressPayload

func NewRootIngressPayload(s *capnp.Segment) (IngressPayload, error)

func ReadRootIngressPayload

func ReadRootIngressPayload(msg *capnp.Message) (IngressPayload, error)

func (IngressPayload) A

func (s IngressPayload) A() int64

func (IngressPayload) B

func (s IngressPayload) B() float64

func (IngressPayload) C

func (s IngressPayload) C() (string, error)

func (IngressPayload) CBytes

func (s IngressPayload) CBytes() ([]byte, error)

func (IngressPayload) D

func (s IngressPayload) D() bool

func (IngressPayload) DecodeFromPtr

func (IngressPayload) DecodeFromPtr(p capnp.Ptr) IngressPayload

func (IngressPayload) EncodeAsPtr

func (s IngressPayload) EncodeAsPtr(seg *capnp.Segment) capnp.Ptr

func (IngressPayload) G1

func (s IngressPayload) G1() int64

func (IngressPayload) G2

func (s IngressPayload) G2() (string, error)

func (IngressPayload) G2Bytes

func (s IngressPayload) G2Bytes() ([]byte, error)

func (IngressPayload) HasC

func (s IngressPayload) HasC() bool

func (IngressPayload) HasG2

func (s IngressPayload) HasG2() bool

func (IngressPayload) HasT1

func (s IngressPayload) HasT1() bool

func (IngressPayload) HasT2

func (s IngressPayload) HasT2() bool

func (IngressPayload) IsValid

func (s IngressPayload) IsValid() bool

func (IngressPayload) Message

func (s IngressPayload) Message() *capnp.Message

func (IngressPayload) One

func (s IngressPayload) One() int64

func (IngressPayload) Rowid

func (s IngressPayload) Rowid() int64

func (IngressPayload) Segment

func (s IngressPayload) Segment() *capnp.Segment

func (IngressPayload) SetA

func (s IngressPayload) SetA(v int64)

func (IngressPayload) SetB

func (s IngressPayload) SetB(v float64)

func (IngressPayload) SetC

func (s IngressPayload) SetC(v string) error

func (IngressPayload) SetD

func (s IngressPayload) SetD(v bool)

func (IngressPayload) SetG1

func (s IngressPayload) SetG1(v int64)

func (IngressPayload) SetG2

func (s IngressPayload) SetG2(v string) error

func (IngressPayload) SetOne

func (s IngressPayload) SetOne(v int64)

func (IngressPayload) SetRowid

func (s IngressPayload) SetRowid(v int64)

func (IngressPayload) SetT1

func (s IngressPayload) SetT1(v string) error

func (IngressPayload) SetT2

func (s IngressPayload) SetT2(v string) error

func (IngressPayload) String

func (s IngressPayload) String() string

func (IngressPayload) T1

func (s IngressPayload) T1() (string, error)

func (IngressPayload) T1Bytes

func (s IngressPayload) T1Bytes() ([]byte, error)

func (IngressPayload) T2

func (s IngressPayload) T2() (string, error)

func (IngressPayload) T2Bytes

func (s IngressPayload) T2Bytes() ([]byte, error)

func (IngressPayload) ToPtr

func (s IngressPayload) ToPtr() capnp.Ptr

type IngressPayload_Future

type IngressPayload_Future struct{ *capnp.Future }

IngressPayload_Future is a wrapper for a IngressPayload promised by a client call.

func (IngressPayload_Future) Struct

type IngressPayload_List

type IngressPayload_List = capnp.StructList[IngressPayload]

IngressPayload_List is a list of IngressPayload.

func NewIngressPayload_List

func NewIngressPayload_List(s *capnp.Segment, sz int32) (IngressPayload_List, error)

NewIngressPayload creates a new list of IngressPayload.

type IngressRow

type IngressRow capnp.Struct

func NewIngressRow

func NewIngressRow(s *capnp.Segment) (IngressRow, error)

func NewRootIngressRow

func NewRootIngressRow(s *capnp.Segment) (IngressRow, error)

func ReadRootIngressRow

func ReadRootIngressRow(msg *capnp.Message) (IngressRow, error)

func (IngressRow) DecodeFromPtr

func (IngressRow) DecodeFromPtr(p capnp.Ptr) IngressRow

func (IngressRow) EncodeAsPtr

func (s IngressRow) EncodeAsPtr(seg *capnp.Segment) capnp.Ptr

func (IngressRow) Group

func (s IngressRow) Group() (Group, error)

func (IngressRow) HasGroup

func (s IngressRow) HasGroup() bool

func (IngressRow) HasPayload

func (s IngressRow) HasPayload() bool

func (IngressRow) IsValid

func (s IngressRow) IsValid() bool

func (IngressRow) Message

func (s IngressRow) Message() *capnp.Message

func (IngressRow) NewGroup

func (s IngressRow) NewGroup() (Group, error)

NewGroup sets the group field to a newly allocated Group struct, preferring placement in s's segment.

func (IngressRow) NewPayload

func (s IngressRow) NewPayload() (IngressPayload, error)

NewPayload sets the payload field to a newly allocated IngressPayload struct, preferring placement in s's segment.

func (IngressRow) Payload

func (s IngressRow) Payload() (IngressPayload, error)

func (IngressRow) Segment

func (s IngressRow) Segment() *capnp.Segment

func (IngressRow) SetGroup

func (s IngressRow) SetGroup(v Group) error

func (IngressRow) SetPayload

func (s IngressRow) SetPayload(v IngressPayload) error

func (IngressRow) String

func (s IngressRow) String() string

func (IngressRow) ToPtr

func (s IngressRow) ToPtr() capnp.Ptr

type IngressRow_Future

type IngressRow_Future struct{ *capnp.Future }

IngressRow_Future is a wrapper for a IngressRow promised by a client call.

func (IngressRow_Future) Group

func (p IngressRow_Future) Group() Group_Future

func (IngressRow_Future) Payload

func (IngressRow_Future) Struct

func (f IngressRow_Future) Struct() (IngressRow, error)

type IngressRow_List

type IngressRow_List = capnp.StructList[IngressRow]

IngressRow_List is a list of IngressRow.

func NewIngressRow_List

func NewIngressRow_List(s *capnp.Segment, sz int32) (IngressRow_List, error)

NewIngressRow creates a new list of IngressRow.

Jump to